Welcome to Pymaker’s documentation! — Pymaker 0.0.1 documentation

# Welcome to Pymaker’s documentation!

Contents:

- Quickstart
- API
  - Exceptions
  - Public Functions
  - Private Functions

Pymaker, the better alternative to make.

    from pymaker import command, r

    @command
    def start():
         r('echo Hello, World!')

    $ pymaker start
    Pymaker: echo Hello, World!
    Hello, World!

Pymaker allows you to use your knowledge of Python in order to define and run repetitive commands.

Although Pymaker is not as intellegent as GNU Make yet, Pymaker allows you to take advantage of Python, which is already a major power boost. In the future, support for C compilers and Python might be available. To see the available features, see the quickstart.

# Indices and tables

- Index

- Module Index

- Search Page